'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('./extends-338edd51.js');
var _styled = require('styled-components');
var React = require('react');
var index = require('./index-00b34fc0.js');
var TextInput = require('./TextInput.js');
var ButtonIcon = require('./ButtonIcon.js');
var Theme = require('./Theme.js');
var IconEyeOff = require('./IconEyeOff.js');
var IconEyeOn = require('./IconEyeOn.js');
var constants = require('./constants.js');
var environment = require('./environment.js');
var textStyles = require('./text-styles.js');
var IconCopy = require('./IconCopy.js');
var miscellaneous = require('./miscellaneous.js');
require('./ButtonBase.js');
require('./FocusVisible.js');
require('./defineProperty-26e0e7dd.js');
require('./keycodes.js');
require('./css.js');
require('./theme-dark.js');
require('./theme-light.js');
require('./color.js');
require('./IconPropTypes-73af9330.js');
require('./index-0416038c.js');
require('./font.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _styled__default = /*#__PURE__*/_interopDefaultLegacy(_styled);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const HEIGHT = 5 * constants.GU;
const TextCopyWithPassword = /*#__PURE__*/React__default["default"].memo( /*#__PURE__*/React__default["default"].forwardRef(function TextCopy(_ref, ref) {
  let {
    adornment,
    autofocus,
    message,
    monospace,
    multiline,
    onCopy,
    value,
    ...props
  } = _ref;
  const theme = Theme.useTheme();
  const inputRef = React.useRef(null);
  const [showPassword, setShowPassword] = React.useState(false); // Allows to focus the component from the outside

  React.useImperativeHandle(ref, () => ({
    focus: () => {
      inputRef.current.focus();
    }
  })); // Select the content on focus

  const handleFocus = React.useCallback(() => {
    inputRef.current && inputRef.current.select();
  }, []); // If onCopy is set (either to a function or null), Toast is not used.

  const onCopyOrToast = onCopy === undefined ? miscellaneous.noop : onCopy || miscellaneous.noop;
  const handleCopy = React.useCallback(() => {
    if (inputRef.current) {
      inputRef.current.focus();

      try {
        navigator.clipboard.writeText(inputRef.current.innerText);
        onCopyOrToast(message);
      } catch (err) {
        environment.warn(err);
      }
    }
  }, [message, onCopyOrToast]);
  const handlePasswordVisibility = React.useCallback(() => {
    setShowPassword(prevShow => !prevShow);
  }, []);
  return /*#__PURE__*/React__default["default"].createElement(_StyledDiv, _extends._extends({}, props, {
    $_css: 40 * constants.GU,
    $_css2: multiline ? HEIGHT + 20 : HEIGHT,
    $_css3: adornment ? `${HEIGHT}px` : '0',
    $_css4: theme.tableBorder
  }), /*#__PURE__*/React__default["default"].createElement(_StyledTextInput, {
    ref: inputRef,
    autofocus: autofocus,
    onFocus: handleFocus,
    readOnly: true,
    value: value,
    wide: true,
    type: showPassword ? 'text' : 'password',
    multiline: showPassword && multiline,
    $_css5: showPassword ? `text-overflow: ellipsis;` : null,
    $_css6: adornment ? `
                  border-top-left-radius: 0;
                  border-bottom-left-radius: 0;
                  border-left: 0;
                ` : '',
    $_css7: textStyles.textStyle('body4'),
    $_css8: theme.surfaceContent
  }), /*#__PURE__*/React__default["default"].createElement(_StyledDiv2, null, /*#__PURE__*/React__default["default"].createElement(_StyledButtonIcon, {
    onClick: handlePasswordVisibility,
    label: "show",
    $_css9: 2 * constants.GU,
    $_css10: 2 * constants.GU,
    $_css11: theme.accentAlternative,
    $_css12: constants.GU + 2
  }, showPassword ? /*#__PURE__*/React__default["default"].createElement(IconEyeOff["default"], {
    size: "small"
  }) : /*#__PURE__*/React__default["default"].createElement(IconEyeOn["default"], {
    size: "small"
  })), /*#__PURE__*/React__default["default"].createElement(_StyledButtonIcon2, {
    onClick: handleCopy,
    label: "Copy",
    $_css13: 2 * constants.GU,
    $_css14: 2 * constants.GU,
    $_css15: theme.accentAlternative,
    $_css16: constants.GU + 4
  }, adornment || /*#__PURE__*/React__default["default"].createElement(IconCopy["default"], {
    size: "small"
  }))));
}));
TextCopyWithPassword.propTypes = {
  adornment: index.PropTypes.node,
  autofocus: index.PropTypes.bool,
  message: index.PropTypes.string,
  monospace: index.PropTypes.bool,
  onCopy: index.PropTypes.func,
  value: index.PropTypes.string,
  multiline: index.PropTypes.bool
};
TextCopyWithPassword.defaultProps = {
  autofocus: false,
  message: 'Copied',
  monospace: true,
  multiline: false
};

var _StyledDiv = _styled__default["default"]("div").withConfig({
  displayName: "TextCopyWithPassword___StyledDiv",
  componentId: "sc-d26pew-0"
})(["position:relative;display:inline-flex;align-items:center;max-width:100%;width:", "px;height:", "px;padding-left:", ";background:", ";"], p => p.$_css, p => p.$_css2, p => p.$_css3, p => p.$_css4);

var _StyledTextInput = _styled__default["default"](TextInput["default"]).withConfig({
  displayName: "TextCopyWithPassword___StyledTextInput",
  componentId: "sc-d26pew-1"
})(["", " resize:none;height:", "px;max-width:100%;border:0px;", ";", ";&:read-only{color:", ";text-shadow:none;}"], p => p.$_css5, HEIGHT, p => p.$_css6, p => p.$_css7, p => p.$_css8);

var _StyledDiv2 = _styled__default["default"]("div").withConfig({
  displayName: "TextCopyWithPassword___StyledDiv2",
  componentId: "sc-d26pew-2"
})(["white-space:nowrap;"]);

var _StyledButtonIcon = _styled__default["default"](ButtonIcon["default"]).withConfig({
  displayName: "TextCopyWithPassword___StyledButtonIcon",
  componentId: "sc-d26pew-3"
})(["width:", "px;height:", "px;border-radius:0;color:", ";margin:", "px;"], p => p.$_css9, p => p.$_css10, p => p.$_css11, p => p.$_css12);

var _StyledButtonIcon2 = _styled__default["default"](ButtonIcon["default"]).withConfig({
  displayName: "TextCopyWithPassword___StyledButtonIcon2",
  componentId: "sc-d26pew-4"
})(["width:", "px;height:", "px;border-radius:0;color:", ";margin-right:", "px;"], p => p.$_css13, p => p.$_css14, p => p.$_css15, p => p.$_css16);

exports["default"] = TextCopyWithPassword;
//# sourceMappingURL=TextCopyWithPassword.js.map
