import _extends from '../../../node_modules/.pnpm/@babel_runtime@7.16.3/node_modules/@babel/runtime/helpers/extends.js';
import _styled from 'styled-components';
import React, { useRef, useState, useImperativeHandle, useCallback } from 'react';
import PropTypes from '../../../node_modules/.pnpm/prop-types@15.7.2/node_modules/prop-types/index.js';
import WrapperTextInput from '../TextInput/TextInput.js';
import ButtonIcon from '../Button/ButtonIcon.js';
import { useTheme } from '../../theme/Theme.js';
import IconEyeOff from '../../icons/components/IconEyeOff.js';
import IconEyeOn from '../../icons/components/IconEyeOn.js';
import { GU } from '../../style/constants.js';
import { warn } from '../../utils/environment.js';
import { textStyle } from '../../style/text-styles.js';
import IconCopy from '../../icons/components/IconCopy.js';
import { noop } from '../../utils/miscellaneous.js';

const HEIGHT = 5 * GU;
const TextCopyWithPassword = /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(function TextCopy(_ref, ref) {
  let {
    adornment,
    autofocus,
    message,
    monospace,
    multiline,
    onCopy,
    value,
    ...props
  } = _ref;
  const theme = useTheme();
  const inputRef = useRef(null);
  const [showPassword, setShowPassword] = useState(false); // Allows to focus the component from the outside

  useImperativeHandle(ref, () => ({
    focus: () => {
      inputRef.current.focus();
    }
  })); // Select the content on focus

  const handleFocus = useCallback(() => {
    inputRef.current && inputRef.current.select();
  }, []); // If onCopy is set (either to a function or null), Toast is not used.

  const onCopyOrToast = onCopy === undefined ? noop : onCopy || noop;
  const handleCopy = useCallback(() => {
    if (inputRef.current) {
      inputRef.current.focus();

      try {
        navigator.clipboard.writeText(inputRef.current.innerText);
        onCopyOrToast(message);
      } catch (err) {
        warn(err);
      }
    }
  }, [message, onCopyOrToast]);
  const handlePasswordVisibility = useCallback(() => {
    setShowPassword(prevShow => !prevShow);
  }, []);
  return /*#__PURE__*/React.createElement(_StyledDiv, _extends({}, props, {
    $_css: 40 * GU,
    $_css2: multiline ? HEIGHT + 20 : HEIGHT,
    $_css3: adornment ? `${HEIGHT}px` : '0',
    $_css4: theme.tableBorder
  }), /*#__PURE__*/React.createElement(_StyledTextInput, {
    ref: inputRef,
    autofocus: autofocus,
    onFocus: handleFocus,
    readOnly: true,
    value: value,
    wide: true,
    type: showPassword ? 'text' : 'password',
    multiline: showPassword && multiline,
    $_css5: showPassword ? `text-overflow: ellipsis;` : null,
    $_css6: adornment ? `
                  border-top-left-radius: 0;
                  border-bottom-left-radius: 0;
                  border-left: 0;
                ` : '',
    $_css7: textStyle('body4'),
    $_css8: theme.surfaceContent
  }), /*#__PURE__*/React.createElement(_StyledDiv2, null, /*#__PURE__*/React.createElement(_StyledButtonIcon, {
    onClick: handlePasswordVisibility,
    label: "show",
    $_css9: 2 * GU,
    $_css10: 2 * GU,
    $_css11: theme.accentAlternative,
    $_css12: GU + 2
  }, showPassword ? /*#__PURE__*/React.createElement(IconEyeOff, {
    size: "small"
  }) : /*#__PURE__*/React.createElement(IconEyeOn, {
    size: "small"
  })), /*#__PURE__*/React.createElement(_StyledButtonIcon2, {
    onClick: handleCopy,
    label: "Copy",
    $_css13: 2 * GU,
    $_css14: 2 * GU,
    $_css15: theme.accentAlternative,
    $_css16: GU + 4
  }, adornment || /*#__PURE__*/React.createElement(IconCopy, {
    size: "small"
  }))));
}));
TextCopyWithPassword.propTypes = {
  adornment: PropTypes.node,
  autofocus: PropTypes.bool,
  message: PropTypes.string,
  monospace: PropTypes.bool,
  onCopy: PropTypes.func,
  value: PropTypes.string,
  multiline: PropTypes.bool
};
TextCopyWithPassword.defaultProps = {
  autofocus: false,
  message: 'Copied',
  monospace: true,
  multiline: false
};

var _StyledDiv = _styled("div").withConfig({
  displayName: "TextCopyWithPassword___StyledDiv",
  componentId: "sc-d26pew-0"
})(["position:relative;display:inline-flex;align-items:center;max-width:100%;width:", "px;height:", "px;padding-left:", ";background:", ";"], p => p.$_css, p => p.$_css2, p => p.$_css3, p => p.$_css4);

var _StyledTextInput = _styled(WrapperTextInput).withConfig({
  displayName: "TextCopyWithPassword___StyledTextInput",
  componentId: "sc-d26pew-1"
})(["", " resize:none;height:", "px;max-width:100%;border:0px;", ";", ";&:read-only{color:", ";text-shadow:none;}"], p => p.$_css5, HEIGHT, p => p.$_css6, p => p.$_css7, p => p.$_css8);

var _StyledDiv2 = _styled("div").withConfig({
  displayName: "TextCopyWithPassword___StyledDiv2",
  componentId: "sc-d26pew-2"
})(["white-space:nowrap;"]);

var _StyledButtonIcon = _styled(ButtonIcon).withConfig({
  displayName: "TextCopyWithPassword___StyledButtonIcon",
  componentId: "sc-d26pew-3"
})(["width:", "px;height:", "px;border-radius:0;color:", ";margin:", "px;"], p => p.$_css9, p => p.$_css10, p => p.$_css11, p => p.$_css12);

var _StyledButtonIcon2 = _styled(ButtonIcon).withConfig({
  displayName: "TextCopyWithPassword___StyledButtonIcon2",
  componentId: "sc-d26pew-4"
})(["width:", "px;height:", "px;border-radius:0;color:", ";margin-right:", "px;"], p => p.$_css13, p => p.$_css14, p => p.$_css15, p => p.$_css16);

export { TextCopyWithPassword as default };
//# sourceMappingURL=TextCopyWithPassword.js.map
